#![allow(clippy::collapsible_else_if)]

pub mod config;
pub mod git;
pub mod graph;
pub mod log;
pub mod stash;
